@@ -311,7 +311,7 @@
 #	endif
 #	ifdef linux
 #		define	DEFAULT_MAILBOX	"/usr/spool/mail"
-#		define	DEFAULT_MAILER	"/usr/bin/smail"
+#		define	DEFAULT_MAILER	"/usr/sbin/sendmail"
 #		define	DEFAULT_PRINTER	"/usr/bin/lpr"
 #	endif
 #	ifdef M_AMIGA
